CREATE OR ALTER VIEW "IDM_RPT_DATA"."IDMRPT_SYSTEM_INFO_V" ("SCHEMANAME", "TABLENAME", "size", "ROWS_ESTIMATED", "ANALYZED", "TOTAL_DB_SIZE") AS 
    SELECT TOP 100 PERCENT
    s.Name AS schemaname, 
    t.NAME AS tablename, 
    SUM(a.used_pages) * 8 AS size, 
    p.rows AS rows_estimated, 
    Max(t.modify_date) as analyzed,
    (SELECT total_size_mb = CAST(SUM(size) * 8. / 1024 AS DECIMAL(8,2))
    FROM sys.master_files WITH(NOWAIT)
    WHERE database_id = DB_ID()) as total_db_size
    FROM 
    sys.tables t 
    INNER JOIN sys.schemas s ON s.schema_id = t.schema_id 
    INNER JOIN sys.indexes i ON t.OBJECT_ID = i.object_id 
    INNER JOIN sys.partitions p ON i.object_id = p.OBJECT_ID AND i.index_id = p.index_id 
    INNER JOIN sys.allocation_units a ON p.partition_id = a.container_id 
    WHERE s.name = 'IDM_RPT_DATA'
    GROUP BY t.Name, s.Name, p.Rows
    HAVING (SUM(a.total_pages) * 8. / 1024 > = 65536 OR SUM(p.rows) > 0)
    ORDER BY s.Name, t.Name
GO 
GRANT SELECT ON IDM_RPT_DATA.idmrpt_system_info_v TO idmrptuser;
CREATE SYNONYM idmrpt_system_info_v for idmrpt_system_info_v;
